# pyMaBoSS

[![PyPI version](https://badge.fury.io/py/maboss.svg)](https://badge.fury.io/py/maboss)
[![Anaconda-Server Badge](https://anaconda.org/colomoto/pymaboss/badges/version.svg)](https://anaconda.org/colomoto/pymaboss)
![build](https://github.com/colomoto/pyMaBoSS/workflows/build/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/colomoto/pyMaBoSS/badge.svg?branch=master)](https://coveralls.io/github/colomoto/pyMaBoSS?branch=master)
[![Documentation Status](https://readthedocs.org/projects/pymaboss/badge/?version=latest)](http://pymaboss.readthedocs.io/en/latest/?badge=latest)

Python interface for the MaBoSS software (https://maboss.curie.fr)

## Installation

### With conda

```
conda install -c colomoto pymaboss
```

### With pip

```
pip install maboss
python -m maboss_setup
```

